;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "meow-tree-sitter" "20251025.333"
  "Tree-sitter powered motions for Meow."
  '((emacs "29.1")
    (meow  "1.2.0"))
  :url "https://github.com/skissue/meow-tree-sitter"
  :commit "af705960ea34763c804e9c3ea16b6fb9645cce0d"
  :revdesc "af705960ea34"
  :keywords '("convenience" "files" "languages" "tools")
  :authors '(("Ad" . "me@skissue.xyz"))
  :maintainers '(("Ad" . "me@skissue.xyz")))
